@@ -1,4 +1,3 @@
-/* $assl: assl.h,v 1.47 2011/06/30 14:17:50 davec Exp $ */
 /*
  * Copyright (c) 2009 Marco Peereboom <marco@peereboom.us>
  *
@@ -22,41 +21,20 @@
 #include <clens.h>
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <err.h>
-#include <errno.h>
-#include <fcntl.h>
-#include <poll.h>
-#include <signal.h>
-#include <string.h>
-#include <unistd.h>
-#include <unistd.h>
-
-#include <sys/socket.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <sys/wait.h>
-#include <sys/queue.h>
-#include <sys/time.h>
-
-#include <netinet/in.h>
-#include <netinet/in_systm.h>
-#include <netinet/ip.h>
-#include <netdb.h>
-
-#include "openssl/bio.h"
-#include "openssl/ssl.h"
-#include "openssl/err.h"
-#include "openssl/engine.h"
+#include <openssl/ssl.h>
 
 /* versioning */
+#define ASSL_STRINGIFY(x)	#x
+#define ASSL_STR(x)		ASSL_STRINGIFY(x)
 #define ASSL_VERSION_MAJOR	0
-#define ASSL_VERSION_MINOR	10
+#define ASSL_VERSION_MINOR	12
 #define ASSL_VERSION_PATCH	0
-#define ASSL_VERSION		"0.10.0"
+#define ASSL_VERSION		ASSL_STR(ASSL_VERSION_MAJOR) "." \
+				ASSL_STR(ASSL_VERSION_MINOR) "." \
+				ASSL_STR(ASSL_VERSION_PATCH)
 
-void	assl_version(int *major, int *minor, int *patch);
+const char	*assl_verstring(void);
+void		 assl_version(int *major, int *minor, int *patch);
 
 #define ASSL_DEFAULT_PORT	"4433"
 
@@ -73,6 +51,11 @@ void	assl_version(int *major, int *minor, int *patch);
 #define ASSL_GF_IGNORE_SELF_SIGNED	(1<<0)
 #define ASSL_GF_IGNORE_EXPIRED		(1<<1)
 
+/* Logging constants */
+#define	ASSL_LOG_MSG		(1)
+#define	ASSL_LOG_WARN		(2)
+#define	ASSL_LOG_ERR		(3)
+
 enum assl_method {
 	ASSL_M_ALL,
 	ASSL_M_ALL_CLIENT,
@@ -92,6 +75,7 @@ struct assl_context {
 	/* generic */
 	int			as_nonblock;	/* 1 when non-block */
 	int			as_server;	/* 1 if server mode */
+	int			as_keepalive;	/* 1 when keepalive is set */
 	SSL			*as_ssl;
 	SSL_SESSION		*as_ssl_session;
 	int			as_sock;
@@ -143,7 +127,7 @@ int			assl_event_accept(struct assl_context *, int,
 			    void (*)(int, short, void *),
 			    void (*)(int, short, void *),
 			    void *);
-void			assl_fatalx(const char *, ...);
+__dead void		assl_fatalx(const char *, ...);
 void			assl_warnx(const char *, ...);
 ssize_t			assl_read(struct assl_context *, void *, size_t);
 ssize_t			assl_write(struct assl_context *, void *, size_t);
@@ -163,6 +147,7 @@ int			assl_use_mem_certs(struct assl_context *, void *);
 int			assl_destroy_mem_certs(void *);
 void			assl_event_enable_write(struct assl_context *);
 void			assl_event_disable_write(struct assl_context *);
+void			assl_set_log_callback(void (*)(int, const char *));
 
 #ifdef __linux__
 #define INFTIM		(-1)
